function n=order(G) 
% order - extract the order of an FOSS object
%
%   n=order(G)
% 
%   G - an FOSS object
%   n - the order

% Copyright (c) Dingyu Xue, Northeastern University, China
% Last modified 28 March, 2017 
% Last modified 18 May, 2022 
   n=length(G.a)*G.alpha;
end
